@@ -5,7 +5,7 @@ use warnings;
 
 our @ISA = qw();
 
-our $VERSION = '0.01'; # VERSION
+our $VERSION = '0.02'; # VERSION
 
 sub show_bar {
     my $num = shift;
@@ -41,6 +41,8 @@ __END__
 
 =pod
 
+=encoding utf-8
+
 =head1 NAME
 
 Term::Spark
@@ -53,7 +55,28 @@ Displays beautiful graphs to use in the terminal
 
 =head2 METHODS
 
-=encoding utf-8
+Returns a string with a single utf8 bar according to the value
+
+    Term::Spark::show_bar($value_for_this_bar, $max_value);
+
+Returns a string with a bunch of utf8 bars according to the values
+
+    Term::Spark::show_graph('max' => $max_value, 'values' => \@values);
+
+Example:
+
+    A script to capture args or STDIN and print a graph:
+
+    use Term::Spark;
+
+    chomp( @ARGV = <STDIN> ) unless @ARGV;
+
+    my @list = sort { $a <=> $b } @ARGV;
+
+    print Term::Spark::show_graph(
+        'max'     => $list[-1],
+        'values'  => \@ARGV,
+    );
 
 =head1 NAME
 
@@ -61,7 +84,7 @@ Term::Spark - Perl extension for dispaying bars in the terminal
 
 =head1 SEE ALSO
 
-Vertical mode: https://github.com/LuRsT/vspark
+Original idea: https://github.com/holman/spark
 
 =head1 AUTHOR
 
